# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL dD Spatial Searching package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Spatial_searching
else:
    import _CGAL_Spatial_searching

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
class Point_with_transformed_distance_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Point_with_transformed_distance_2_swiginit(self, _CGAL_Spatial_searching.new_Point_with_transformed_distance_2(*args))
    first = property(_CGAL_Spatial_searching.Point_with_transformed_distance_2_first_get, _CGAL_Spatial_searching.Point_with_transformed_distance_2_first_set)
    second = property(_CGAL_Spatial_searching.Point_with_transformed_distance_2_second_get, _CGAL_Spatial_searching.Point_with_transformed_distance_2_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Point_with_transformed_distance_2

# Register Point_with_transformed_distance_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Point_with_transformed_distance_2_swigregister(Point_with_transformed_distance_2)

class Point_with_transformed_distance_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Point_with_transformed_distance_3_swiginit(self, _CGAL_Spatial_searching.new_Point_with_transformed_distance_3(*args))
    first = property(_CGAL_Spatial_searching.Point_with_transformed_distance_3_first_get, _CGAL_Spatial_searching.Point_with_transformed_distance_3_first_set)
    second = property(_CGAL_Spatial_searching.Point_with_transformed_distance_3_second_get, _CGAL_Spatial_searching.Point_with_transformed_distance_3_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Point_with_transformed_distance_3

# Register Point_with_transformed_distance_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Point_with_transformed_distance_3_swigregister(Point_with_transformed_distance_3)

class Fuzzy_sphere_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_sphere_2_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_sphere_2(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_sphere_2_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_sphere_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_sphere_2

# Register Fuzzy_sphere_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_sphere_2_swigregister(Fuzzy_sphere_2)

class Fuzzy_iso_box_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_iso_box_2_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_iso_box_2(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_2_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_iso_box_2

# Register Fuzzy_iso_box_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_iso_box_2_swigregister(Fuzzy_iso_box_2)

class Fuzzy_sphere_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_sphere_3_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_sphere_3(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_sphere_3_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_sphere_3_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_sphere_3

# Register Fuzzy_sphere_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_sphere_3_swigregister(Fuzzy_sphere_3)

class Fuzzy_iso_box_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Fuzzy_iso_box_3_swiginit(self, _CGAL_Spatial_searching.new_Fuzzy_iso_box_3(*args))

    def contains(self, c):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_3_contains(self, c)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Fuzzy_iso_box_3_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Fuzzy_iso_box_3

# Register Fuzzy_iso_box_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Fuzzy_iso_box_3_swigregister(Fuzzy_iso_box_3)

class Orthogonal_incremental_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_2

# Register Orthogonal_incremental_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_2_swigregister(Orthogonal_incremental_neighbor_search_tree_2)

class Orthogonal_incremental_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_2

# Register Orthogonal_incremental_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_2_swigregister(Orthogonal_incremental_neighbor_search_2)

class Orthogonal_incremental_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_iterator_2

# Register Orthogonal_incremental_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_2_swigregister(Orthogonal_incremental_neighbor_search_tree_iterator_2)

class Orthogonal_incremental_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_iterator_2

# Register Orthogonal_incremental_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_2_swigregister(Orthogonal_incremental_neighbor_search_iterator_2)

class Incremental_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_2

# Register Incremental_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_2_swigregister(Incremental_neighbor_search_tree_2)

class Incremental_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_2_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_2_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_2

# Register Incremental_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_2_swigregister(Incremental_neighbor_search_2)

class Incremental_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_iterator_2

# Register Incremental_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_2_swigregister(Incremental_neighbor_search_tree_iterator_2)

class Incremental_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_iterator_2

# Register Incremental_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_iterator_2_swigregister(Incremental_neighbor_search_iterator_2)

class K_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_2

# Register K_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_2_swigregister(K_neighbor_search_tree_2)

class K_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_2_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_2

# Register K_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_2_swigregister(K_neighbor_search_2)

class K_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_iterator_2

# Register K_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_iterator_2_swigregister(K_neighbor_search_tree_iterator_2)

class K_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_iterator_2

# Register K_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_iterator_2_swigregister(K_neighbor_search_iterator_2)

class Orthogonal_k_neighbor_search_tree_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_2(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_2

# Register Orthogonal_k_neighbor_search_tree_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_2_swigregister(Orthogonal_k_neighbor_search_tree_2)

class Orthogonal_k_neighbor_search_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_2(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_2

# Register Orthogonal_k_neighbor_search_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_2_swigregister(Orthogonal_k_neighbor_search_2)

class Orthogonal_k_neighbor_search_tree_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_iterator_2

# Register Orthogonal_k_neighbor_search_tree_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_2_swigregister(Orthogonal_k_neighbor_search_tree_iterator_2)

class Orthogonal_k_neighbor_search_iterator_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_iterator_2())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_iterator_2

# Register Orthogonal_k_neighbor_search_iterator_2 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_2_swigregister(Orthogonal_k_neighbor_search_iterator_2)

class Orthogonal_incremental_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_3

# Register Orthogonal_incremental_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_3_swigregister(Orthogonal_incremental_neighbor_search_tree_3)

class Orthogonal_incremental_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_3

# Register Orthogonal_incremental_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_3_swigregister(Orthogonal_incremental_neighbor_search_3)

class Orthogonal_incremental_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_tree_iterator_3

# Register Orthogonal_incremental_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_tree_iterator_3_swigregister(Orthogonal_incremental_neighbor_search_tree_iterator_3)

class Orthogonal_incremental_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_incremental_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_incremental_neighbor_search_iterator_3

# Register Orthogonal_incremental_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_incremental_neighbor_search_iterator_3_swigregister(Orthogonal_incremental_neighbor_search_iterator_3)

class Incremental_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_3

# Register Incremental_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_3_swigregister(Incremental_neighbor_search_tree_3)

class Incremental_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Incremental_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_3_iterator(self)

    def value(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_3_value(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_3

# Register Incremental_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_3_swigregister(Incremental_neighbor_search_3)

class Incremental_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_tree_iterator_3

# Register Incremental_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_tree_iterator_3_swigregister(Incremental_neighbor_search_tree_iterator_3)

class Incremental_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Incremental_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Incremental_neighbor_search_iterator_3

# Register Incremental_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Incremental_neighbor_search_iterator_3_swigregister(Incremental_neighbor_search_iterator_3)

class K_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_3

# Register K_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_3_swigregister(K_neighbor_search_tree_3)

class K_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.K_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.K_neighbor_search_3_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_3

# Register K_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_3_swigregister(K_neighbor_search_3)

class K_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_tree_iterator_3

# Register K_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_tree_iterator_3_swigregister(K_neighbor_search_tree_iterator_3)

class K_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.K_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_K_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.K_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_K_neighbor_search_iterator_3

# Register K_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.K_neighbor_search_iterator_3_swigregister(K_neighbor_search_iterator_3)

class Orthogonal_k_neighbor_search_tree_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_3(*args))

    def insert(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_insert(self, *args)

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_iterator(self)

    def clear(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_clear(self)

    def size(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_size(self)

    def search(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_search(self, *args)

    def build(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_build(self)

    def same_internal_object(self, other):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_same_internal_object(self, other)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_3

# Register Orthogonal_k_neighbor_search_tree_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_3_swigregister(Orthogonal_k_neighbor_search_tree_3)

class Orthogonal_k_neighbor_search_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_3(*args))

    def iterator(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_iterator(self)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_3

# Register Orthogonal_k_neighbor_search_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_3_swigregister(Orthogonal_k_neighbor_search_3)

class Orthogonal_k_neighbor_search_tree_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_tree_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_tree_iterator_3

# Register Orthogonal_k_neighbor_search_tree_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_tree_iterator_3_swigregister(Orthogonal_k_neighbor_search_tree_iterator_3)

class Orthogonal_k_neighbor_search_iterator_3(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_swiginit(self, _CGAL_Spatial_searching.new_Orthogonal_k_neighbor_search_iterator_3())

    def __iter__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___iter__(self)

    def __next__(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___next__(self)

    def next(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3___ne__(self, p)
    __swig_destroy__ = _CGAL_Spatial_searching.delete_Orthogonal_k_neighbor_search_iterator_3

# Register Orthogonal_k_neighbor_search_iterator_3 in _CGAL_Spatial_searching:
_CGAL_Spatial_searching.Orthogonal_k_neighbor_search_iterator_3_swigregister(Orthogonal_k_neighbor_search_iterator_3)



