print("import: 'CGAL'")
import CGAL

print("import: 'CGAL.CGAL_Kernel'")
import CGAL.CGAL_Kernel

print("import: 'CGAL.CGAL_Triangulation_2'")
import CGAL.CGAL_Triangulation_2

print("import: 'CGAL.CGAL_AABB_tree'")
import CGAL.CGAL_AABB_tree

